import 'package:flutter/material.dart';
import 'dart:async';

import 'package:flutter/services.dart';
import 'package:flutter_uninstall/flutter_uninstall.dart';

void main() {
  runApp(const MyApp());
}

class MyApp extends StatefulWidget {
  const MyApp({Key? key}) : super(key: key);

  @override
  State<MyApp> createState() => _MyAppState();
}

class _MyAppState extends State<MyApp> {
  String _platformVersion = 'Unknown';
  final String _packageName = 'com.flutter.uninstall.flutter_uninstall_example';
  bool _isInstall = false;

  @override
  void initState() {
    super.initState();
    initPlatformState();
    initInstallState();
  }

  // Platform messages are asynchronous, so we initialize in an async method.
  Future<void> initPlatformState() async {
    String platformVersion;
    // Platform messages may fail, so we use a try/catch PlatformException.
    // We also handle the message potentially returning null.
    try {
      platformVersion =
          await FlutterUninstall.platformVersion ?? 'Unknown platform version';
    } on PlatformException {
      platformVersion = 'Failed to get platform version.';
    }

    // If the widget was removed from the tree while the asynchronous platform
    // message was in flight, we want to discard the reply rather than calling
    // setState to update our non-existent appearance.
    if (!mounted) return;

    setState(() {
      _platformVersion = platformVersion;
    });
  }

  // Platform messages are asynchronous, so we initialize in an async method.
  Future<void> initInstallState() async {
    bool install = await FlutterUninstall.isInstallApp(_packageName) ?? false;

    // If the widget was removed from the tree while the asynchronous platform
    // message was in flight, we want to discard the reply rather than calling
    // setState to update our non-existent appearance.
    if (!mounted) return;

    setState(() {
      _isInstall = install;
    });
  }

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      home: Scaffold(
        appBar: AppBar(
          title: const Text('Plugin example app'),
        ),
        body: Center(
          child: Column(
            mainAxisAlignment: MainAxisAlignment.center,
            children: [
              Text('Running on: $_platformVersion\n'),
              Visibility(
                visible: _isInstall,
                child: TextButton(
                  onPressed:  () async {
                    FlutterUninstall.uninstallApp(_packageName);
                  },
                  child: Container(
                    padding: const EdgeInsets.only(left: 20, right: 20, top: 5, bottom: 5),
                    color: const Color(0xffff0000),
                    child: const Text('卸载'),
                  ),
                ),
              ),
            ],
          ),
        ),
      ),
    );
  }
}
