
import 'dart:async';
import 'dart:ffi';

import 'package:flutter/services.dart';

class FlutterUninstall {
  static const MethodChannel _channel = MethodChannel('flutter_uninstall');

  static Future<String?> get platformVersion async {
    final String? version = await _channel.invokeMethod('getPlatformVersion');
    return version;
  }

  static Future<String?> getVersionName(String packageName) async {
    final Map map = {"packageName": packageName};
    final String? versionName = await _channel.invokeMethod('getVersionName', map);
    return versionName;
  }

  static Future<int> getVersionCode(String packageName) async {
    final Map map = {"packageName": packageName};
    final int versionCode = await _channel.invokeMethod('getVersionCode', map);
    return versionCode;
  }

  static Future<String?> getAppLabel(String packageName) async {
    final Map map = {"packageName": packageName};
    final String? label = await _channel.invokeMethod('getAppLabel', map);
    return label;
  }

  static Future<List<Object?>> getPackagesByLabel(String label) async {
    final Map map = {"label": label};
    final List<Object?> package = await _channel.invokeMethod('getPackagesByLabel', map);
    return package;
  }

  static Future<bool?> isInstallApp(String packageName) async {
    final Map map = {"packageName": packageName};
    final bool? install = await _channel.invokeMethod('isInstallApp', map);
    return install;
  }

  static Future<void> uninstallApp(String packageName) async {
    final Map map = {"packageName": packageName};
    await _channel.invokeMethod('uninstallApp', map);
  }
}
